<?php
if ( ! class_exists( 'IPCpop_Admin' )) {

    /**
     * Class for handling administrator page
     */
    class IPCpop_Admin
    {
        /**
         * Show content admin home
         *
         * @return void
         */
        public function index()
        {
            $this->view( 'list' );
        }
        
        /**
         * Show content for create content pop
         *
         * @return void
         */
        public function create()
        {
            $this->_manage();
        }
        
        /**
         * Show content for update content pop
         *
         * @return void
         */
        public function update()
        {
            if ( empty( $_GET['id'] )) {
                wp_die( __('You attempted to edit an item that doesn&#8217;t exist. Perhaps it was deleted?', 'wp-popper-pro') );
            }
            $id = absint( $_GET['id'] );
            if ( ! $content = get_post( $id ) ) {
                wp_die( __('You attempted to edit an item that doesn&#8217;t exist. Perhaps it was deleted?', 'wp-popper-pro') );
            }
            $this->_manage( $content );
        }
        
        /**
         * Show content for manage content pop
         *
         * @param  array $content
         * @return void
         */
        protected function _manage( $content = false )
        {
            wp_enqueue_media();
            wp_enqueue_script('wp-color-picker');
            wp_enqueue_style('wp-color-picker');
            
            $contentId = 0;
            if ( $content ) {
                $contentId = $content->ID;
            }
            $setting = new IPCpop_Setting( $contentId, '__ipcpop-setting' );
            
            $this->setting   = $setting;
            $this->content   = $content;
            $this->contentId = $contentId;
               
            $tab = 'ipcpop-section-general';
            if ( ! empty( $_REQUEST['tab'] )) {
                $tab = $_REQUEST['tab'];
            }
            $this->tab = $tab;
            
            $this->view( 'manage' );
        }
        
        /**
         * Get admin view file
         *
         * @param string $filename
         * @return void
         */
        public function view( $filename )
        {
            $path  = IPCPOP_PATH . 'app/views/admin/';
            $path .= strtolower( $filename ) . '.php'; 
            if ( file_exists( $path )) {
                include( $path );
            }
        }
        
        /**
         * Admin header template
         *
         * @param string $page
         * @return void
         */
        public function header( $page, $title = '', $info = '', $icon = '', $isAdd = true )
        {
            $struct = array(
                'ipcpop' => array(
                    'title'     => __( 'Dashboard', 'wp-popper-pro' ),
                    'info'      => __( 'See all content popups and manage it', 'wp-popper-pro' ),
                    'icon'      => 'dashboard'
                ),
                'ipcpop-create' => array(
                    'title'     => __( 'Add New Content', 'wp-popper-pro' ),
                    'info'      => __( 'Create new content pop up for your website', 'wp-popper-pro' ),
                    'icon'      => 'plus-circle'
                )
            );
        ?>
            <div class="ipbe-top">
                <div class="ipbe-header">
                    <div class="ipbe-page-title">
                        <h1>
                            <i class="ibe ibe-list-alt"></i>
                            <span>
                                <strong><span>WP</span> Popper Pro</strong>
                                <em><?php _e( 'WordPress plugin that is used to to show a content pop up in your page/post.','wp-popper-pro' ); ?></em>
                            </span>
                        </h1>
                    </div>
                </div>
                <div class="ipbe-nav">
                    <ul>
                    <?php
                    $addButton = false;
                    if ( array_key_exists( $page, $struct ))
                    {
                        if ( empty( $title )) {
                            $title = $struct[$page]['title'];
                        }
                        if ( empty( $info )) {
                            $info  = $struct[$page]['info'];
                        }
                        if ( empty( $icon )) {
                            $icon  = $struct[$page]['icon'];
                        }
                        if ( ! empty( $struct[$page]['add'] ) && $isAdd ) {
                            $addButton = $struct[$page]['add'];
                        }
                    }
                    foreach( $struct as $name => $data ) 
                    {
                        $active = '';
                        if ( $page == $name ) {
                            $active = ' class="active"';
                        }
                        echo '<li' . $active . '>' .
                                '<a href="admin.php?page=' . $name . '">' .
                                    '<i class="ibe ibe-' . $data['icon'] . '"></i>' .
                                    $data['title'] .
                                '</a>' .
                            '</li>';
                    }
                    ?>
                    </ul>
                </div>
                <div class="ipbe-page-info">
                    <div class="container-fluid container">
                        <div class="row">
                            <div class="col-md-8 ipbe-page-info-main">
                                <i class="ibe ibe-<?php echo $icon; ?>"></i>
                                <div class="ipbe-info">
                                    <h2><?php echo $title; ?></h2>
                                    <h3><?php echo $info; ?></h3>
                                </div>
                            </div>
                            <div class="col-md-4 text-right">
                                <?php
                                if ( $addButton ) :
                                ?>
                                <a href="<?php echo $addButton['link']; ?>" class="ipbe-btn ipbe-btn-success ipbe-btn-lg">
                                    <i class="ibe ibe-plus"></i>
                                    <?php echo $addButton['title']; ?>
                                </a>
                                <?php
                                endif;
                                ?>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        <?php
        }
    }
}